#
# Extract list of Office365 endpoints for WebMarshal consumption
#
param (
[string]$savePath = "."
)
[Net.ServicePointManager]::SecurityProtocol = [Net.SecurityProtocolType]::tls12
$requestGuid = New-Guid
$endpoints = (Invoke-WebRequest -Uri "https://endpoints.office.com/endpoints/worldwide?clientrequestid=$requestGuid") | ConvertFrom-Json

$serviceAreas = "Exchange","Skype","Sharepoint","Common"

$listId=5
$allUrls = "Microsoft365_AllUrls.txt"
New-Item -Path $savePath -Name $allUrls -ItemType "file" -Force | Out-Null
Add-Content -Path "$savePath\$allUrls" -Value "[236$listId Microsoft 365]`n" 
$allUrlsArray = [System.Collections.ArrayList]::new()
$currUrlsArray = [System.Collections.ArrayList]::new()

$listId++

foreach ($sa in $serviceAreas)
{
$currUrlsArray.Clear()

#Below line restricts 
#$pts = $endpoints | Where-Object { $_.serviceArea -eq $sa -and $_.required -eq $true -and ($_.tcpPorts -eq "443" -or $_.tcpPorts -eq "80" -or $_.tcpPorts -eq "80,443")} 
$pts = $endpoints | Where-Object { $_.serviceArea -eq $sa -and ($_.tcpPorts -eq "443" -or $_.tcpPorts -eq "80" -or $_.tcpPorts -eq "80,443")} 
$filename = "Microsoft365_$sa.txt"     
New-Item -Path $savePath -Name $filename -ItemType "file" -Force | Out-Null

Add-Content -Path "$savePath\$filename" -Value "[236$listId Microsoft 365 $sa]`n" 

foreach ($ep in $pts)
{   
    foreach ($u in $ep.urls) {
        if ($ep.tcpPorts.IndexOf('80') -ge 0)  {
            $plainUrl = "http://$u/"
            if (!$currUrlsArray.Contains($plainUrl)) {
                Add-Content -Path "$savePath\$filename" -Value $plainUrl
                [void]$currUrlsArray.Add($plainUrl)
            }
            if (!$allUrlsArray.Contains($plainUrl)) {
                Add-Content -Path "$savePath\$allUrls" -Value $plainUrl
                [void]$allUrlsArray.Add($plainUrl)
            }
        }
        if ($ep.tcpPorts.IndexOf('443') -ge 0) {  
            $secureUrl = "https://$u/"      
            if (!$currUrlsArray.Contains($secureUrl)) {
                Add-Content -Path "$savePath\$filename" -Value $secureUrl
                [void]$currUrlsArray.Add($secureUrl)
                }
            if (!$allUrlsArray.Contains($secureUrl)) {
                    Add-Content -Path "$savePath\$allUrls" -Value $secureUrl 
                    [void]$allUrlsArray.Add($secureUrl)
                }
            }
    }
}
$listId++
}
